==> amsdal_cli-0.1.15.tar.gz: amsdal_cli-0.1.15/src/amsdal_cli/commands/cloud/deploy/sub_commands/deploy_new.py <==
import typing
from pathlib import Path

import typer
from amsdal.cloud.enums import DeployType
from amsdal.cloud.enums import LakehouseOption
from amsdal.errors import AmsdalCloudError
from amsdal.manager import AmsdalManager
from amsdal_utils.config.manager import AmsdalConfigManager
from rich import print
from typer import Option

from amsdal_cli.commands.cloud.deploy.app import deploy_sub_app
from amsdal_cli.commands.cloud.deploy.app import deprecated_deploy_sub_app
from amsdal_cli.commands.cloud.environments.utils import get_current_env
from amsdal_cli.utils.cli_config import CliConfig


@deploy_sub_app.command('new, n')
def deploy_command(
    ctx: typer.Context,
    deploy_type: DeployType = DeployType.include_state_db,
    lakehouse_type: LakehouseOption = LakehouseOption.postgres,
    env_name: typing.Annotated[
        typing.Optional[str],  # noqa: UP007
        Option('--env', help='Environment name. Default is the current environment from configratuion.'),
    ] = None,
    from_env: typing.Optional[str] = Option(None, '--from-env', help='Environment name to copy from.'),  # noqa: UP007
    *,
    no_input: bool = Option(False, '--no-input', help='Do not prompt for input.'),
    skip_checks: bool = Option(
        False,
        '--skip-checks',
        help='Skip checking secrets and dependencies before deploying.',
    ),
) -> None:
    env_name = env_name or get_current_env(ctx)
    cli_config: CliConfig = ctx.meta['config']

    if cli_config.verbose:
        print(f'[blue]Deploying to environment: [dark_cyan]{env_name}[/dark_cyan][/blue]')

    AmsdalConfigManager().load_config(Path('./config.yml'))
    manager = AmsdalManager()
    manager.authenticate()

    if not skip_checks:
        try:
            list_response_deps = manager.cloud_actions_manager.list_dependencies(
                env_name=env_name,
                application_uuid=cli_config.application_uuid,
                application_name=cli_config.application_name,
            )
        except AmsdalCloudError as e:
            print(f'[red]Failed to loading dependencies: {e}[/red]')
            raise typer.Exit(1) from e

        config_dir: Path = cli_config.app_directory / '.amsdal'
        config_dir.mkdir(exist_ok=True, parents=True)
        _deps_path: Path = config_dir / '.dependencies'
        _deps_path.touch(exist_ok=True)
        _deps = set(_deps_path.read_text().split('\n'))
        _diff_deps = list(filter(None, _deps - set(list_response_deps.dependencies)))

        if _diff_deps:
            print(f'[yellow]The following dependencies are missing: {", ".join(_diff_deps)}[/yellow]')

            if no_input:
                print('[blue]Installing missing dependencies...[/blue]')
                install_deps = True
            else:
                install_deps = typer.confirm('Do you want to install the missing dependencies?')

            if not install_deps:
                print('[blue]Use "amsdal cloud dependencies new NAME" to install the missing dependencies.[/blue]')
                raise typer.Exit(1)

            for dependency_name in _diff_deps:
                try:
                    manager.cloud_actions_manager.add_dependency(
                        dependency_name=dependency_name,
                        env_name=env_name,
                        application_uuid=cli_config.application_uuid,
                        application_name=cli_config.application_name,
                    )
                except AmsdalCloudError as e:
                    print(f'[red]{e}[/red]')
                    raise typer.Exit(1) from e

        try:
            list_response_secrets = manager.cloud_actions_manager.list_secrets(
                with_values=False,
                env_name=env_name,
                application_uuid=cli_config.application_uuid,
                application_name=cli_config.application_name,
            )
        except AmsdalCloudError as e:
            print(f'[red]Failed to loading secrets: {e}[/red]')
            raise typer.Exit(1) from e

        _secrets_path: Path = config_dir / '.secrets'
        _secrets_path.touch(exist_ok=True)
        _secrets = set(_secrets_path.read_text().split('\n'))
        _diff_secrets = list(filter(None, _secrets - set(list_response_secrets.secrets)))

        if _diff_secrets:
            print(f'[red]The following secrets are missing: {", ".join(_diff_secrets)}[/red]')
            raise typer.Exit(1)

    try:
        manager.cloud_actions_manager.create_deploy(
            deploy_type=deploy_type.value,
            lakehouse_type=lakehouse_type.value,
            env_name=env_name,
            from_env=from_env,
            application_uuid=cli_config.application_uuid,
            application_name=cli_config.application_name,
            no_input=no_input,
        )
    except AmsdalCloudError as e:
        print(f'[red]{e}[/red]')
        raise typer.Exit(1) from e


@deprecated_deploy_sub_app.callback(invoke_without_command=True)
def deploy_command_deprecated(
    ctx: typer.Context,
    deploy_type: DeployType = DeployType.include_state_db,
    lakehouse_type: LakehouseOption = LakehouseOption.postgres,
    *,
    no_input: bool = Option(False, '--no-input', help='Do not prompt for input.'),
    skip_checks: bool = Option(
        False,
        '--skip-checks',
        help='Skip checking secrets and dependencies before deploying.',
    ),
) -> None:
    """
    Deploy the app to the Cloud Server.
    """

    if ctx.invoked_subcommand is not None:
        return

    deploy_command(
        ctx=ctx,
        deploy_type=deploy_type,
        lakehouse_type=lakehouse_type,
        no_input=no_input,
        skip_checks=skip_checks,
    )

==> amsdal_cli-0.1.18.tar.gz: amsdal_cli-0.1.18/src/amsdal_cli/commands/cloud/deploy/sub_commands/deploy_new.py <==
import typing
from pathlib import Path

import typer
from amsdal.cloud.enums import DeployType
from amsdal.cloud.enums import LakehouseOption
from amsdal.errors import AmsdalCloudError
from amsdal.manager import AmsdalManager
from amsdal_utils.config.manager import AmsdalConfigManager
from rich import print
from typer import Option

from amsdal_cli.commands.cloud.deploy.app import deploy_sub_app
from amsdal_cli.commands.cloud.deploy.app import deprecated_deploy_sub_app
from amsdal_cli.commands.cloud.environments.utils import get_current_env
from amsdal_cli.utils.cli_config import CliConfig
from amsdal_cli.utils.text import CustomConfirm
from amsdal_cli.utils.text import rich_error
from amsdal_cli.utils.text import rich_highlight
from amsdal_cli.utils.text import rich_info
from amsdal_cli.utils.text import rich_warning


@deploy_sub_app.command('new, n')
def deploy_command(
    ctx: typer.Context,
    deploy_type: DeployType = DeployType.include_state_db,
    lakehouse_type: LakehouseOption = LakehouseOption.postgres,
    env_name: typing.Annotated[
        typing.Optional[str],  # noqa: UP007
        Option('--env', help='Environment name. Default is the current environment from configratuion.'),
    ] = None,
    from_env: typing.Optional[str] = Option(None, '--from-env', help='Environment name to copy from.'),  # noqa: UP007
    *,
    no_input: bool = Option(False, '--no-input', help='Do not prompt for input.'),
    skip_checks: bool = Option(
        False,
        '--skip-checks',
        help='Skip checking secrets and dependencies before deploying.',
    ),
) -> None:
    cli_config: CliConfig = ctx.meta['config']
    env_name = env_name or get_current_env(cli_config)

    if cli_config.verbose:
        print(rich_info(f'Deploying to environment: {rich_highlight(env_name)}'))

    AmsdalConfigManager().load_config(Path('./config.yml'))
    manager = AmsdalManager()
    manager.authenticate()

    if not skip_checks:
        try:
            list_response_deps = manager.cloud_actions_manager.list_dependencies(
                env_name=env_name,
                application_uuid=cli_config.application_uuid,
                application_name=cli_config.application_name,
            )
        except AmsdalCloudError as e:
            print(rich_error(f'Failed to loading dependencies: {e}'))
            raise typer.Exit(1) from e

        config_dir: Path = cli_config.app_directory / '.amsdal'
        config_dir.mkdir(exist_ok=True, parents=True)
        _deps_path: Path = config_dir / '.dependencies'
        _deps_path.touch(exist_ok=True)
        _deps = set(_deps_path.read_text().split('\n'))
        _diff_deps = list(filter(None, _deps - set(list_response_deps.dependencies)))

        if _diff_deps:
            print(rich_warning(f'The following dependencies are missing: {", ".join(map(rich_highlight, _diff_deps))}'))

            if no_input:
                print(rich_info('Installing missing dependencies...'))
                install_deps = True
            else:
                install_deps = CustomConfirm.ask(
                    rich_info('Do you want to install the missing dependencies?'),
                    default=False,
                    show_default=False,
                    choices=['y', 'N'],
                )

            if not install_deps:
                print(rich_info('Use "amsdal cloud dependencies new NAME" to install the missing dependencies.'))
                raise typer.Exit(1)

            for dependency_name in _diff_deps:
                try:
                    manager.cloud_actions_manager.add_dependency(
                        dependency_name=dependency_name,
                        env_name=env_name,
                        application_uuid=cli_config.application_uuid,
                        application_name=cli_config.application_name,
                    )
                except AmsdalCloudError as e:
                    print(rich_error(str(e)))
                    raise typer.Exit(1) from e

        try:
            list_response_secrets = manager.cloud_actions_manager.list_secrets(
                with_values=False,
                env_name=env_name,
                application_uuid=cli_config.application_uuid,
                application_name=cli_config.application_name,
            )
        except AmsdalCloudError as e:
            print(rich_error(f'Failed to loading secrets: {e}'))
            raise typer.Exit(1) from e

        _secrets_path: Path = config_dir / '.secrets'
        _secrets_path.touch(exist_ok=True)
        _secrets = set(_secrets_path.read_text().split('\n'))
        _diff_secrets = list(filter(None, _secrets - set(list_response_secrets.secrets)))

        if _diff_secrets:
            print(rich_error(f'The following secrets are missing: {", ".join(_diff_secrets)}'))
            raise typer.Exit(1)

    try:
        manager.cloud_actions_manager.create_deploy(
            deploy_type=deploy_type.value,
            lakehouse_type=lakehouse_type.value,
            env_name=env_name,
            from_env=from_env,
            application_uuid=cli_config.application_uuid,
            application_name=cli_config.application_name,
            no_input=no_input,
        )
    except AmsdalCloudError as e:
        if str(e) in ['Same environment name', 'same_environment_name']:
            print(
                rich_error(
                    f'Trying to deploy {rich_highlight(env_name)} environment from '
                    f'{rich_highlight(str(from_env))}. Please check the environment names.'
                )
            )
        elif str(e) in ['Environment not found', 'environment_not_found']:
            if from_env:
                print(
                    rich_error(f'Environment {rich_highlight(from_env)} not found. Please check the environment name.')
                )
            else:
                print(
                    rich_error(f'Environment {rich_highlight(env_name)} not found. Please check the environment name.')
                )

        elif str(e) in ['Environment not deployed', 'environment_not_deployed']:
            print(
                rich_error(
                    f'Environment {rich_highlight(str(from_env))} is not deployed. '
                    'Please check the environment name.'
                )
            )

        else:
            print(rich_error(str(e)))

        raise typer.Exit(1) from e


@deprecated_deploy_sub_app.callback(invoke_without_command=True)
def deploy_command_deprecated(
    ctx: typer.Context,
    deploy_type: DeployType = DeployType.include_state_db,
    lakehouse_type: LakehouseOption = LakehouseOption.postgres,
    *,
    no_input: bool = Option(False, '--no-input', help='Do not prompt for input.'),
    skip_checks: bool = Option(
        False,
        '--skip-checks',
        help='Skip checking secrets and dependencies before deploying.',
    ),
) -> None:
    """
    Deploy the app to the Cloud Server.
    """

    if ctx.invoked_subcommand is not None:
        return

    deploy_command(
        ctx=ctx,
        deploy_type=deploy_type,
        lakehouse_type=lakehouse_type,
        no_input=no_input,
        skip_checks=skip_checks,
    )
